@@ -66,7 +66,7 @@ handle_error (void *cls)
  */
 static void
 handle_existing_records (void *cls,
-                         const struct GNUNET_IDENTITY_PrivateKey *zone,
+                         const struct GNUNET_CRYPTO_PrivateKey *zone,
                          const char *label,
                          unsigned int rd_count,
                          const struct GNUNET_GNSRECORD_Data *rd)
@@ -104,7 +104,7 @@ gnunet_conversation_gtk_enter_label_entry_changed_cb (GtkEditable *editable,
   const gchar *label;
   GtkWidget *b_add;
   struct GNUNET_IDENTITY_Ego *ego;
-  const struct GNUNET_IDENTITY_PrivateKey *pkey;
+  const struct GNUNET_CRYPTO_PrivateKey *pkey;
   const char *tld;
 
   if (NULL != qe)
