@@ -23,6 +23,7 @@
  * @brief Main function of gnunet-fs-gtk
  * @author Christian Grothoff
  */
+#include "gnunet_gtk.h"
 #include "gnunet-fs-gtk.h"
 #include "gnunet-fs-gtk_common.h"
 #include "gnunet-fs-gtk_event-handler.h"
@@ -151,6 +152,7 @@ GNUNET_FS_GTK_get_fs_handle ()
   return fs;
 }
 
+
 /**
  * Get an object from the main window.
  *
@@ -166,7 +168,6 @@ get_object (const char *name)
 }
 
 
-
 /**
  * Remember FS handle if we don't have one yet.
  *
@@ -180,15 +181,17 @@ GNUNET_FS_GTK_set_fs_handle (struct GNUNET_FS_Handle *fsh)
 }
 
 
-/**
- * Get our configuration.
- *
- * @return configuration handle
- */
 const struct GNUNET_CONFIGURATION_Handle *
-GNUNET_FS_GTK_get_configuration ()
+GNUNET_FS_GTK_get_gnunet_configuration ()
 {
-  return GNUNET_GTK_main_loop_get_configuration (ml);
+  return GNUNET_GTK_main_loop_get_gnunet_configuration (ml);
+}
+
+
+const struct GNUNET_CONFIGURATION_Handle *
+GNUNET_FS_GTK_get_gnunet_gtk_configuration ()
+{
+  return GNUNET_GTK_main_loop_get_gtk_configuration (ml);
 }
 
 
@@ -237,8 +240,6 @@ main_window_save_position (GtkWidget *main_window)
   struct GNUNET_CONFIGURATION_Handle *cfg;
   struct GNUNET_CONFIGURATION_Handle *cfgDefault;
 
-  cfg = (struct GNUNET_CONFIGURATION_Handle *)
-        GNUNET_GTK_main_loop_get_configuration (ml);
   main_window_gdk = gtk_widget_get_window (main_window);
   maximized = GNUNET_YES;
   if (NULL != main_window_gdk)
@@ -251,6 +252,8 @@ main_window_save_position (GtkWidget *main_window)
   gtk_window_get_position (GTK_WINDOW (main_window), &window_x, &window_y);
   gtk_window_get_size (GTK_WINDOW (main_window), &window_width, &window_height);
 
+  cfg = (struct GNUNET_CONFIGURATION_Handle *)
+        GNUNET_GTK_main_loop_get_gtk_configuration (ml);
   GNUNET_CONFIGURATION_set_value_number (cfg,
                                          "gnunet-fs-gtk",
                                          "MAIN_WINDOW_X",
@@ -273,12 +276,13 @@ main_window_save_position (GtkWidget *main_window)
                                          (maximized == GNUNET_YES) ? "YES"
                                                                    : "NO");
 
-  cfgDefault = GNUNET_CONFIGURATION_create ();
-  (void) GNUNET_CONFIGURATION_load (cfgDefault, NULL); /* load defaults only */
-  GNUNET_CONFIGURATION_write_diffs (cfgDefault,
-                                    cfg,
-                                    GNUNET_GTK_main_loop_get_configuration_file (
-                                      ml));
+  cfgDefault = GNUNET_CONFIGURATION_create (GNUNET_GTK_project_data ());
+  (void) GNUNET_CONFIGURATION_load (cfgDefault,
+                                    NULL); /* load defaults only */
+  GNUNET_CONFIGURATION_write_diffs (
+    cfgDefault,
+    cfg,
+    GNUNET_GTK_main_loop_get_gtk_configuration_file (ml));
   GNUNET_CONFIGURATION_destroy (cfgDefault);
 }
 
@@ -377,7 +381,8 @@ shutdown_task (void *cls)
  * @param user_data global builder instance, unused
  */
 void
-GNUNET_FS_GTK_menu_quit_activate_cb (GtkMenuItem *object, gpointer user_data)
+GNUNET_FS_GTK_menu_quit_activate_cb (GtkMenuItem *object,
+                                     gpointer user_data)
 {
   GNUNET_SCHEDULER_shutdown ();
 }
@@ -415,7 +420,9 @@ GNUNET_FS_GTK_delete_event_cb (GtkWidget *object,
  * @param data NULL
  */
 static void
-process_paste (GtkClipboard *cb, const gchar *text, gpointer data)
+process_paste (GtkClipboard *cb,
+               const gchar *text,
+               gpointer data)
 {
   struct GNUNET_FS_Uri *kskuri;
   char *emsg;
@@ -732,11 +739,11 @@ handle_sks_zone_identity (void *cls,
                                  "main_window_search_namespace_combobox")));
   if (NULL != main_context.zm)
   {
-    GNUNET_NAMESTORE_zone_monitor_stop(main_context.zm);
+    GNUNET_NAMESTORE_zone_monitor_stop (main_context.zm);
     main_context.zm = NULL;
   }
   main_context.zm =
-    GNUNET_NAMESTORE_zone_monitor_start (main_context.cfg,
+    GNUNET_NAMESTORE_zone_monitor_start (main_context.gnunet_cfg,
                                          GNUNET_IDENTITY_ego_get_private_key (
                                            main_context.sks_zone),
                                          GNUNET_YES,
@@ -779,6 +786,7 @@ gnunet_fs_gtk_id_combobox_changed_cb (GtkComboBox *widget,
   handle_sks_zone_identity (name, ego);
 }
 
+
 /**
  * Method called to inform about the egos of this peer.  Updates the
  * `zone_liststore`.
@@ -876,6 +884,7 @@ identity_cb (void *cls,
   gtk_list_store_set (id_liststore, &iter, ID_LS_NAME, name, -1);
 }
 
+
 /**
  * Actual main function run right after GNUnet's scheduler
  * is initialized.  Initializes up GTK and Glade.
@@ -898,7 +907,10 @@ run (void *cls)
   if (GNUNET_OK != GNUNET_GTK_main_loop_build_window (ml, &main_context))
     return;
   main_context.builder = GNUNET_GTK_main_loop_get_builder (ml);
-  main_context.cfg = GNUNET_GTK_main_loop_get_configuration (ml);
+  main_context.gnunet_gtk_cfg
+    = GNUNET_GTK_main_loop_get_gtk_configuration (ml);
+  main_context.gnunet_cfg
+    = GNUNET_GTK_main_loop_get_gnunet_configuration (ml);
   main_context.search_ns_treestore =
     GTK_TREE_STORE (GNUNET_FS_GTK_get_main_window_object (
                       "main_window_search_namespace_treestore"));
@@ -976,30 +988,36 @@ run (void *cls)
   g_object_set (gtk_settings_get_default (), "gtk-button-images", TRUE, NULL);
 
   /* setup main window */
-  maximized = GNUNET_CONFIGURATION_get_value_yesno (main_context.cfg,
+  maximized = GNUNET_CONFIGURATION_get_value_yesno (main_context.gnunet_gtk_cfg,
                                                     "gnunet-fs-gtk",
                                                     "MAIN_WINDOW_MAXIMIZED");
   if (GNUNET_SYSERR == maximized)
     maximized = GNUNET_YES;
   if ((GNUNET_NO == maximized) &&
-      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
-                                                           "gnunet-fs-gtk",
-                                                           "MAIN_WINDOW_X",
-                                                           &window_x)) &&
-      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
-                                                           "gnunet-fs-gtk",
-                                                           "MAIN_WINDOW_Y",
-                                                           &window_y)) &&
-      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
-                                                           "gnunet-fs-gtk",
-                                                           "MAIN_WINDOW_WIDTH",
-                                                           &window_width)) &&
-      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
-                                                           "gnunet-fs-gtk",
-                                                           "MAIN_WINDOW_HEIGHT",
-                                                           &window_height)))
+      (GNUNET_OK ==
+       GNUNET_CONFIGURATION_get_value_number (main_context.gnunet_gtk_cfg,
+                                              "gnunet-fs-gtk",
+                                              "MAIN_WINDOW_X",
+                                              &window_x)) &&
+      (GNUNET_OK ==
+       GNUNET_CONFIGURATION_get_value_number (main_context.gnunet_gtk_cfg,
+                                              "gnunet-fs-gtk",
+                                              "MAIN_WINDOW_Y",
+                                              &window_y)) &&
+      (GNUNET_OK ==
+       GNUNET_CONFIGURATION_get_value_number (main_context.gnunet_gtk_cfg,
+                                              "gnunet-fs-gtk",
+                                              "MAIN_WINDOW_WIDTH",
+                                              &window_width)) &&
+      (GNUNET_OK ==
+       GNUNET_CONFIGURATION_get_value_number (main_context.gnunet_gtk_cfg,
+                                              "gnunet-fs-gtk",
+                                              "MAIN_WINDOW_HEIGHT",
+                                              &window_height)))
   {
-    gtk_window_move (GTK_WINDOW (main_context.main_window), window_x, window_y);
+    gtk_window_move (GTK_WINDOW (main_context.main_window),
+                     window_x,
+                     window_y);
     gtk_window_resize (GTK_WINDOW (main_context.main_window),
                        window_width,
                        window_height);
@@ -1021,19 +1039,19 @@ run (void *cls)
    * default config files?
    */
   if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+      GNUNET_CONFIGURATION_get_value_number (main_context.gnunet_gtk_cfg,
                                              "gnunet-fs-gtk",
                                              "MAX_PARALLEL_DOWNLOADS",
                                              &dl_parallel))
     dl_parallel = DEFAULT_MAX_PARALLEL_DOWNLOADS;
   if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+      GNUNET_CONFIGURATION_get_value_number (main_context.gnunet_gtk_cfg,
                                              "gnunet-fs-gtk",
                                              "MAX_PARALLEL_REQUESTS",
                                              &req_parallel))
     req_parallel = DEFAULT_MAX_PARALLEL_REQUESTS;
   /* initialize file-sharing */
-  fs = GNUNET_FS_start (main_context.cfg,
+  fs = GNUNET_FS_start (main_context.gnunet_cfg,
                         "gnunet-fs-gtk",
                         &GNUNET_GTK_fs_event_handler,
                         NULL,
@@ -1048,15 +1066,17 @@ run (void *cls)
     GNUNET_GTK_main_loop_quit (cls);
     return;
   }
-  arm = GNUNET_ARM_connect (main_context.cfg,
+  arm = GNUNET_ARM_connect (main_context.gnunet_cfg,
                             &arm_connection_state_change,
                             &main_context);
-  armon = GNUNET_ARM_monitor_start (main_context.cfg,
+  armon = GNUNET_ARM_monitor_start (main_context.gnunet_cfg,
                                     &service_status_change,
                                     &main_context);
-  main_context.gns = GNUNET_GNS_connect (main_context.cfg);
-  main_context.identity = GNUNET_IDENTITY_connect (main_context.cfg,
-                                                   &identity_cb, NULL);
+  main_context.gns = GNUNET_GNS_connect (main_context.gnunet_cfg);
+  main_context.identity
+    = GNUNET_IDENTITY_connect (main_context.gnunet_cfg,
+                               &identity_cb,
+                               NULL);
 #if HAVE_LIBUNIQUE
   unique_app_watch_window (unique_app, GTK_WINDOW (main_context.main_window));
   g_signal_connect (unique_app,
@@ -1121,7 +1141,8 @@ main (int argc, char **argv)
 
 #endif
   if (GNUNET_OK !=
-      GNUNET_GTK_main_loop_start ("gnunet-fs-gtk",
+      GNUNET_GTK_main_loop_start (GNUNET_GTK_project_data (),
+                                  "gnunet-fs-gtk",
                                   "GTK GUI for GNUnet",
                                   argc,
                                   argv,
