@@ -33,7 +33,7 @@
  * How long until we decide a SKS namespace GNS lookup has failed?
  */
 #define LOOKUP_TIMEOUT \
-  GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 2)
+        GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 2)
 
 
 /**
@@ -45,8 +45,10 @@ beep ()
   gdk_display_beep (gdk_screen_get_display (
                       gdk_window_get_screen (gtk_widget_get_parent_window (
                                                GTK_WIDGET (
-                                                 GNUNET_FS_GTK_get_main_window_object (
-                                                   "GNUNET_GTK_main_window"))))));
+                                                 GNUNET_FS_GTK_get_main_window_object
+                                                 (
+                                                   "GNUNET_GTK_main_window")))))
+                    );
 }
 
 
@@ -396,7 +398,7 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   struct GNUNET_GTK_MainWindowContext *main_ctx;
   struct GNUNET_NAMESTORE_RecordInfo ri;
   unsigned int ret;
-  
+
   GNUNET_break (NULL == lctx->nick);
   lctx->nick = GNUNET_strdup (nick);
   /* again, show progress indicator, this should be fast though... */
@@ -415,7 +417,7 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   rd.expiration_time = GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us;
   rd.record_type = GNUNET_GNSRECORD_TYPE_PKEY;
   main_ctx = GNUNET_FS_GTK_get_main_context ();
-  lctx->namestore = GNUNET_NAMESTORE_connect (main_ctx->cfg);
+  lctx->namestore = GNUNET_NAMESTORE_connect (main_ctx->gnunet_cfg);
   GNUNET_assert (NULL != lctx->namestore);
   ri.a_label = nick;
   ri.a_rd_count = 1;
@@ -425,8 +427,8 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
                                     GNUNET_IDENTITY_ego_get_private_key (
                                       main_ctx->sks_zone),
                                     1,
-				    &ri,
-				    &ret,
+                                    &ri,
+                                    &ret,
                                     &store_continuation,
                                     lctx);
 }
