@@ -45,7 +45,6 @@ struct AddChildContext
    * Anonymity level to use for probes in the directory.
    */
   uint32_t anonymity;
-
 };
 
 
@@ -66,8 +65,11 @@ struct AddChildContext
  * @param data data available for the file (@a length bytes)
  */
 static void
-add_child (void *cls, const char *filename, const struct GNUNET_FS_Uri *uri,
-           const struct GNUNET_CONTAINER_MetaData *meta, size_t length,
+add_child (void *cls,
+           const char *filename,
+           const struct GNUNET_FS_Uri *uri,
+           const struct GNUNET_FS_MetaData *meta,
+           size_t length,
            const void *data)
 {
   struct AddChildContext *acc = cls;
@@ -75,17 +77,18 @@ add_child (void *cls, const char *filename, const struct GNUNET_FS_Uri *uri,
   if (NULL == uri)
   {
     /* directory meta data itself, create parent entry */
-    struct GNUNET_CONTAINER_MetaData *dmeta;
+    struct GNUNET_FS_MetaData *dmeta;
 
-    dmeta = GNUNET_CONTAINER_meta_data_duplicate (meta);
-    GNUNET_CONTAINER_meta_data_insert (dmeta, "<user>",
+    dmeta = GNUNET_FS_meta_data_duplicate (meta);
+    GNUNET_FS_meta_data_insert (dmeta,
+                                       "<user>",
                                        EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME,
-                                       EXTRACTOR_METAFORMAT_UTF8, "text/plain",
+                                       EXTRACTOR_METAFORMAT_UTF8,
+                                       "text/plain",
                                        acc->filename,
                                        strlen (acc->filename) + 1);
-    acc->sr = GNUNET_GTK_add_to_uri_tab (acc->anonymity,
-					 dmeta, NULL);
-    GNUNET_CONTAINER_meta_data_destroy (dmeta);
+    acc->sr = GNUNET_GTK_add_to_uri_tab (acc->anonymity, dmeta, NULL);
+    GNUNET_FS_meta_data_destroy (dmeta);
     return;
   }
   if (NULL == acc->sr)
@@ -93,12 +96,13 @@ add_child (void *cls, const char *filename, const struct GNUNET_FS_Uri *uri,
     GNUNET_break (0);
     return;
   }
-  GNUNET_assert (NULL !=
-                 GNUNET_GTK_add_search_result (acc->sr->tab,
-					       acc->anonymity,
-					       acc->sr->rr,
-					       uri,
-                                               meta, NULL, 0));
+  GNUNET_assert (NULL != GNUNET_GTK_add_search_result (acc->sr->tab,
+                                                       acc->anonymity,
+                                                       acc->sr->rr,
+                                                       uri,
+                                                       meta,
+                                                       NULL,
+                                                       0));
 }
 
 
@@ -124,12 +128,14 @@ GNUNET_GTK_open_directory_dialog_response_cb (GtkDialog *dialog,
     g_object_unref (G_OBJECT (builder));
     return;
   }
-  filename = GNUNET_GTK_filechooser_get_filename_utf8 (GTK_FILE_CHOOSER (dialog));
+  filename =
+    GNUNET_GTK_filechooser_get_filename_utf8 (GTK_FILE_CHOOSER (dialog));
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   acc.filename = filename;
   acc.sr = NULL;
-  acc.anonymity = 1; // FIXME, might want to add this to dialog to allow user to set it.
+  acc.anonymity =
+    1; // FIXME, might want to add this to dialog to allow user to set it.
   GNUNET_FS_GTK_mmap_and_scan (filename, &add_child, &acc);
   GNUNET_free (filename);
 }
@@ -143,7 +149,7 @@ GNUNET_GTK_open_directory_dialog_response_cb (GtkDialog *dialog,
  * @param data the main dialog builder, unused
  */
 void
-GNUNET_GTK_main_menu_file_open_gnunet_directory_activate_cb (GtkWidget * dummy,
+GNUNET_GTK_main_menu_file_open_gnunet_directory_activate_cb (GtkWidget *dummy,
                                                              gpointer data)
 {
   GtkWidget *ad;
@@ -152,16 +158,17 @@ GNUNET_GTK_main_menu_file_open_gnunet_directory_activate_cb (GtkWidget * dummy,
   GtkFileFilter *ff;
 
   builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_open_directory_dialog.glade", NULL);
+    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_open_directory_dialog.glade",
+                                NULL);
   if (NULL == builder)
   {
     GNUNET_break (0);
     return;
   }
-  ad = GTK_WIDGET (gtk_builder_get_object
-                   (builder, "GNUNET_GTK_open_directory_dialog"));
-  ff = GTK_FILE_FILTER (gtk_builder_get_object
-                        (builder, "gnunet_directory_filter"));
+  ad = GTK_WIDGET (
+    gtk_builder_get_object (builder, "GNUNET_GTK_open_directory_dialog"));
+  ff = GTK_FILE_FILTER (
+    gtk_builder_get_object (builder, "gnunet_directory_filter"));
   /* FIXME-FEATURE: some day, write a custom file filter for gnunet-directories... */
   gtk_file_filter_add_pattern (ff, "*" GNUNET_FS_DIRECTORY_EXT);
 
