@@ -557,7 +557,8 @@ update_selectivity_edit (struct MainPublishingDialogContext *ctx)
  * @param user_data master publishing dialog context of our window
  */
 void
-GNUNET_GTK_master_publish_dialog_file_informatino_treeview_selection_changed_cb (
+GNUNET_GTK_master_publish_dialog_file_informatino_treeview_selection_changed_cb
+(
   GtkTreeSelection *ts,
   gpointer user_data)
 {
@@ -942,7 +943,8 @@ GNUNET_GTK_master_publish_dialog_identifier_entry_changed_cb (
  * @param user_data master publishing dialog context of our window
  */
 void
-GNUNET_GTK_master_publish_dialog_previous_identifiers_treeview_selection_changed_cb (
+GNUNET_GTK_master_publish_dialog_previous_identifiers_treeview_selection_changed_cb
+(
   GtkTreeSelection *ts,
   gpointer user_data)
 {
@@ -1883,12 +1885,14 @@ GNUNET_GTK_master_publish_dialog_add_button_clicked_cb (GtkWidget *dummy,
   gtk_spin_button_set_value (
     GTK_SPIN_BUTTON (gtk_builder_get_object (
                        ctx->open_file_builder,
-                       "GNUNET_GTK_publish_file_dialog_replication_spin_button")),
+                       "GNUNET_GTK_publish_file_dialog_replication_spin_button")
+                     ),
     0);
   gtk_toggle_button_set_active (
     GTK_TOGGLE_BUTTON (gtk_builder_get_object (
                          ctx->open_file_builder,
-                         "GNUNET_GTK_publish_file_dialog_do_index_checkbutton")),
+                         "GNUNET_GTK_publish_file_dialog_do_index_checkbutton"))
+    ,
     TRUE);
 
   {
@@ -2305,7 +2309,7 @@ GNUNET_GTK_master_publish_dialog_execute_button_clicked_cb (GtkButton *button,
   do_own = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ctx->own_checkbox));
 
   disable_ads_insertion = GNUNET_CONFIGURATION_get_value_yesno (
-    GNUNET_FS_GTK_get_configuration (),
+    GNUNET_FS_GTK_get_gnunet_gtk_configuration (),
     "gnunet-fs-gtk",
     "DISABLE_AUTOMATIC_NAMESPACE_ADVERTISEMENT_INSERTION");
   if (disable_ads_insertion == GNUNET_SYSERR)
@@ -2991,7 +2995,6 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
                                                gpointer user_data)
 {
   struct MainPublishingDialogContext *ctx;
-  const struct GNUNET_CONFIGURATION_Handle *cfg;
   GtkWidget *toplevel;
   int updateable_enabled;
   int own_enabled;
@@ -3043,7 +3046,8 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
 
   ctx->global_checkbox = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder,
-                            "GNUNET_GTK_master_publish_dialog_global_checkbox"));
+                            "GNUNET_GTK_master_publish_dialog_global_checkbox"))
+  ;
   ctx->own_checkbox = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_master_publish_dialog_own_checkbox"));
@@ -3052,7 +3056,8 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
                                            "GNUNET_GTK_master_publish_dialog_updateable_checkbox"));
   ctx->update_id_entry = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder,
-                            "GNUNET_GTK_master_publish_dialog_update_id_entry"));
+                            "GNUNET_GTK_master_publish_dialog_update_id_entry"))
+  ;
 
   ctx->own_vbox = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder,
@@ -3073,7 +3078,8 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
 
   ctx->identifier_entry = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder,
-                            "GNUNET_GTK_master_publish_dialog_identifier_entry"));
+                            "GNUNET_GTK_master_publish_dialog_identifier_entry")
+    );
   ctx->identifiers_scrolled = GTK_WIDGET (gtk_builder_get_object (
                                             ctx->builder,
                                             "GNUNET_GTK_master_publish_dialog_previous_identifiers_scrolled"));
@@ -3090,25 +3096,29 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
                     G_CALLBACK (expander_callback),
                     ctx);
 
-  cfg = GNUNET_FS_GTK_get_configuration ();
-  ctx->identity = GNUNET_IDENTITY_connect (cfg, &add_namespace_to_ts, ctx);
+  ctx->identity
+    = GNUNET_IDENTITY_connect (GNUNET_FS_GTK_get_gnunet_configuration (),
+                               &add_namespace_to_ts,
+                               ctx);
 
   updateable_enabled = GNUNET_CONFIGURATION_get_value_yesno (
-    cfg,
+    GNUNET_FS_GTK_get_gnunet_gtk_configuration (),
     "gnunet-fs-gtk",
     "MAKE_UPDATEABLE_PUBLICATIONS_BY_DEFAULT");
   if (GNUNET_SYSERR == updateable_enabled)
     updateable_enabled = GNUNET_YES;
   own_enabled =
-    GNUNET_CONFIGURATION_get_value_yesno (cfg,
-                                          "gnunet-fs-gtk",
-                                          "MAKE_NAMESPACE_PUBLICATIONS_BY_DEFAULT");
+    GNUNET_CONFIGURATION_get_value_yesno (
+      GNUNET_FS_GTK_get_gnunet_gtk_configuration (),
+      "gnunet-fs-gtk",
+      "MAKE_NAMESPACE_PUBLICATIONS_BY_DEFAULT");
   if (GNUNET_SYSERR == own_enabled)
     own_enabled = GNUNET_NO;
   global_enabled =
-    GNUNET_CONFIGURATION_get_value_yesno (cfg,
-                                          "gnunet-fs-gtk",
-                                          "MAKE_GLOBAL_PUBLICATIONS_BY_DEFAULT");
+    GNUNET_CONFIGURATION_get_value_yesno (
+      GNUNET_FS_GTK_get_gnunet_gtk_configuration (),
+      "gnunet-fs-gtk",
+      "MAKE_GLOBAL_PUBLICATIONS_BY_DEFAULT");
   if (GNUNET_SYSERR == global_enabled)
     global_enabled = GNUNET_YES;
 
