@@ -27,7 +27,6 @@
 #define GNUNET_GTK_H
 
 #include <gnunet/gnunet_util_lib.h>
-#include <gnunet/gnunet_fs_service.h>
 #include <gtk/gtk.h>
 #include <gladeui/glade.h>
 #include <gdk/gdkkeysyms.h>
@@ -178,7 +177,8 @@ GNUNET_GTK_filechooser_get_filename_utf8 (GtkFileChooser *fc);
  * @param root root of the subtree to remove
  */
 void
-GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore *ts, GtkTreeIter *root);
+GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore *ts,
+                                        GtkTreeIter *root);
 
 
 /* ******************* main loop ***************** */
@@ -187,6 +187,7 @@ GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore *ts, GtkTreeIter *root);
 /**
  * Initialize the main loop.
  *
+ * @param pd project data of the program we are launching
  * @param binary_name binary name
  * @param binary_help help text for the binary
  * @param argc number of command line options
@@ -199,13 +200,15 @@ GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore *ts, GtkTreeIter *root);
  * options, etc)
  */
 int
-GNUNET_GTK_main_loop_start (const char *binary_name,
-                            const char *binary_help,
-                            int argc,
-                            char *const *argv,
-                            struct GNUNET_GETOPT_CommandLineOption *options,
-                            const char *main_window_file,
-                            GNUNET_SCHEDULER_TaskCallback main_task);
+GNUNET_GTK_main_loop_start (
+  const struct GNUNET_OS_ProjectData *pd,
+  const char *binary_name,
+  const char *binary_help,
+  int argc,
+  char *const *argv,
+  struct GNUNET_GETOPT_CommandLineOption *options,
+  const char *main_window_file,
+  GNUNET_SCHEDULER_TaskCallback main_task);
 
 
 /**
@@ -256,13 +259,26 @@ GNUNET_GTK_main_loop_build_window (struct GNUNET_GTK_MainLoop *ml,
 
 
 /**
- * Obtain the name of the configuration file that is being used.
+ * Obtain the name of the configuration file that is being used
+ * by gnunet-gtk.
  *
  * @param ml handle to the main loop
  * @return name of configuration file
  */
 const char *
-GNUNET_GTK_main_loop_get_configuration_file (struct GNUNET_GTK_MainLoop *ml);
+GNUNET_GTK_main_loop_get_gtk_configuration_file (
+  struct GNUNET_GTK_MainLoop *ml);
+
+/**
+ * Obtain the name of the configuration file that is being used
+ * by GNUnet (core).
+ *
+ * @param ml handle to the main loop
+ * @return name of configuration file
+ */
+const char *
+GNUNET_GTK_main_loop_get_gnunet_configuration_file (
+  struct GNUNET_GTK_MainLoop *ml);
 
 
 /**
@@ -272,7 +288,18 @@ GNUNET_GTK_main_loop_get_configuration_file (struct GNUNET_GTK_MainLoop *ml);
  * @return handle to the configuration, never NULL
  */
 const struct GNUNET_CONFIGURATION_Handle *
-GNUNET_GTK_main_loop_get_configuration (struct GNUNET_GTK_MainLoop *ml);
+GNUNET_GTK_main_loop_get_gtk_configuration (
+  struct GNUNET_GTK_MainLoop *ml);
+
+
+/**
+ * Get the configuration.
+ *
+ * @param ml handle to the main loop
+ * @return handle to the configuration, never NULL
+ */
+const struct GNUNET_CONFIGURATION_Handle *
+GNUNET_GTK_main_loop_get_gnunet_configuration (struct GNUNET_GTK_MainLoop *ml);
 
 
 /**
@@ -438,5 +465,12 @@ GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo,
                                                guint *p_level);
 
 
+/**
+ * Return default project data used by gnunet-gtk.
+ */
+const struct GNUNET_OS_ProjectData *
+GNUNET_GTK_project_data (void);
+
+
 #endif
 /* end of gnunet_gtk.h */
