@@ -45,9 +45,14 @@ struct GNUNET_GTK_MainLoop
 {
 
   /**
-   * Our configuration (includes defaults from gnunet-gtk/config.d/ and gnunet/config.d/)
+   * Our configuration (includes defaults from gnunet-gtk/config.d/)
    */
-  struct GNUNET_CONFIGURATION_Handle *cfg;
+  struct GNUNET_CONFIGURATION_Handle *gnunet_gtk_cfg;
+
+  /**
+   * GNUnet configuration (includes defaults from gnunet/config.d/)
+   */
+  struct GNUNET_CONFIGURATION_Handle *gnunet_cfg;
 
   /**
    * Name of the glade file for the main window
@@ -90,9 +95,14 @@ struct GNUNET_GTK_MainLoop
   GPollFD *cached_poll_array;
 
   /**
-   * Name of the configuration file.
+   * Name of the configuration file for gnunet-gtk.
    */
-  char *cfgfile;
+  char *gnunet_gtk_cfgfile;
+
+  /**
+   * Name of the configuration file for GNUnet (core).
+   */
+  char *gnunet_cfgfile;
 
   /**
    * Size of the 'cached_poll_array'.
@@ -124,9 +134,23 @@ struct GNUNET_GTK_MainLoop
  * @return handle to the configuration, never NULL
  */
 const struct GNUNET_CONFIGURATION_Handle *
-GNUNET_GTK_main_loop_get_configuration (struct GNUNET_GTK_MainLoop *ml)
+GNUNET_GTK_main_loop_get_gnunet_configuration (struct GNUNET_GTK_MainLoop *ml)
 {
-  return ml->cfg;
+  return ml->gnunet_cfg;
+}
+
+
+/**
+ * Get the configuration.
+ *
+ * @param ml handle to the main loop
+ * @return handle to the configuration, never NULL
+ */
+const struct GNUNET_CONFIGURATION_Handle *
+GNUNET_GTK_main_loop_get_gtk_configuration (
+  struct GNUNET_GTK_MainLoop *ml)
+{
+  return ml->gnunet_gtk_cfg;
 }
 
 
@@ -182,9 +206,24 @@ GNUNET_GTK_main_loop_build_window (struct GNUNET_GTK_MainLoop *ml,
  * @return name of configuration file
  */
 const char *
-GNUNET_GTK_main_loop_get_configuration_file (struct GNUNET_GTK_MainLoop *ml)
+GNUNET_GTK_main_loop_get_gnunet_configuration_file (
+  struct GNUNET_GTK_MainLoop *ml)
 {
-  return ml->cfgfile;
+  return ml->gnunet_cfgfile;
+}
+
+
+/**
+ * Obtain the name of the configuration file that is being used.
+ *
+ * @param ml handle to the main loop
+ * @return name of configuration file
+ */
+const char *
+GNUNET_GTK_main_loop_get_gtk_configuration_file (
+  struct GNUNET_GTK_MainLoop *ml)
+{
+  return ml->gnunet_gtk_cfgfile;
 }
 
 
@@ -444,7 +483,7 @@ gnunet_gtk_select (void *cls,
  *
  * @param cls the `struct GNUNET_GTK_MainLoop`
  * @param args leftover command line arguments (go to gtk)
- * @param cfgfile name of the configuration file
+ * @param cfgfile name of the gnunet-gtk configuration file
  * @param cfg handle to the configuration
  */
 static void
@@ -454,6 +493,7 @@ run_main_loop (void *cls,
                const struct GNUNET_CONFIGURATION_Handle *cfg)
 {
   struct GNUNET_GTK_MainLoop *ml = cls;
+  const struct GNUNET_OS_ProjectData *pd;
   struct GNUNET_CONFIGURATION_Handle *gcfg;
   char *baseconfig;
   char *ipath2;
@@ -461,52 +501,96 @@ run_main_loop (void *cls,
   int argc;
 
   /* command-line processing for Gtk arguments */
+  pd = GNUNET_CONFIGURATION_get_project_data (cfg);
   argc = 0;
   while (args[argc] != NULL)
     argc++;
   gtk_init (&argc, (char ***) &args);
-  gcfg = GNUNET_CONFIGURATION_create ();
+  gcfg = GNUNET_CONFIGURATION_create (pd);
 
-  if (NULL == (ipath = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_DATADIR)))
+  if (NULL == (ipath = GNUNET_OS_installation_get_path (
+                 pd,
+                 GNUNET_OS_IPK_DATADIR)))
   {
     GNUNET_break (0);
     return;
   }
-  GNUNET_asprintf (&baseconfig, "%s%s", ipath, "config.d");
-  (void) GNUNET_CONFIGURATION_load_from (gcfg, baseconfig);
+  GNUNET_asprintf (&baseconfig,
+                   "%s%s",
+                   ipath,
+                   "config.d");
+  (void) GNUNET_CONFIGURATION_load_from (gcfg,
+                                         baseconfig);
   GNUNET_free (baseconfig);
-  /* FIXME: this was supposed to search the GTK-IPK, so the logic here is badly broken now */
   if (NULL ==
-      (ipath2 = GNUNET_OS_installation_get_path (GNUNET_OS_IPK_DATADIR)))
+      (ipath2 = GNUNET_OS_installation_get_path (pd,
+                                                 GNUNET_OS_IPK_DATADIR)))
   {
     GNUNET_break (0);
     return;
   }
   if (0 != strcmp (ipath, ipath2))
   {
-    GNUNET_asprintf (&baseconfig, "%s%s", ipath2, "config.d");
-    if (GNUNET_YES == GNUNET_DISK_directory_test (baseconfig, GNUNET_YES))
-      (void) GNUNET_CONFIGURATION_load_from (gcfg, baseconfig);
+    GNUNET_asprintf (&baseconfig,
+                     "%s%s",
+                     ipath2,
+                     "config.d");
+    if (GNUNET_YES ==
+        GNUNET_DISK_directory_test (baseconfig,
+                                    GNUNET_YES))
+      (void) GNUNET_CONFIGURATION_load_from (gcfg,
+                                             baseconfig);
     GNUNET_free (baseconfig);
   }
   GNUNET_free (ipath2);
   GNUNET_free (ipath);
 
   if (GNUNET_YES == GNUNET_DISK_file_test (cfgfile))
-    (void) GNUNET_CONFIGURATION_parse (gcfg, cfgfile);
+    (void) GNUNET_CONFIGURATION_parse (gcfg,
+                                       cfgfile);
   ml->rs = GNUNET_NETWORK_fdset_create ();
   ml->ws = GNUNET_NETWORK_fdset_create ();
   ml->gml = g_main_loop_new (NULL, TRUE);
   ml->gmc = g_main_loop_get_context (ml->gml);
-  ml->cfg = gcfg;
+  ml->gnunet_gtk_cfg = gcfg;
+  if (NULL == ml->gnunet_cfgfile)
+  {
+    const char *xdg = getenv ("XDG_CONFIG_HOME");
+
+    if (NULL != xdg)
+      GNUNET_asprintf (
+        &ml->gnunet_cfgfile,
+        "%s%s%s",
+        xdg,
+        DIR_SEPARATOR_STR,
+        GNUNET_CONFIGURATION_get_project_data (cfg)->config_file);
+    else
+      ml->gnunet_cfgfile
+        = GNUNET_strdup (
+            GNUNET_CONFIGURATION_get_project_data (cfg)->user_config_file);
+  }
+  ml->gnunet_cfg
+    = GNUNET_CONFIGURATION_create (GNUNET_OS_project_data_gnunet ());
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_load (ml->gnunet_cfg,
+                                 ml->gnunet_cfgfile))
+  {
+    GNUNET_break (0);
+    GNUNET_SCHEDULER_shutdown ();
+    return;
+  }
+  /* FIXME: add command-line option to allow parsing
+     a configuration file for gnunet_cfg as well! */
+
   if (NULL != cfgfile)
-    ml->cfgfile = GNUNET_strdup (cfgfile);
+    ml->gnunet_gtk_cfgfile = GNUNET_strdup (cfgfile);
   ml->argc = argc;
   ml->argv = args;
 
   /* start the Gtk event loop */
-  GNUNET_assert (TRUE == g_main_context_acquire (ml->gmc));
-  GNUNET_SCHEDULER_set_select (&gnunet_gtk_select, ml);
+  GNUNET_assert (g_main_context_acquire (ml->gmc));
+  GNUNET_SCHEDULER_set_select (&gnunet_gtk_select,
+                               ml);
 
   /* keep Gtk event loop running even if there are no GNUnet tasks */
   ml->dummy_task = GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_FOREVER_REL,
@@ -521,40 +605,56 @@ run_main_loop (void *cls,
 }
 
 
-/**
- * Initialize the main loop.
- *
- * @param binary_name binary name
- * @param binary_help help text for the binary
- * @param argc number of command line options
- * @param argv command line options
- * @param options allowed command line options
- * @param main_window_file glade file for the main window
- * @param main_task first task to run, closure will be set to the `struct GNUNET_GTK_MainLoop`
- * @return #GNUNET_OK on success, #GNUNET_SYSERR on error (i.e. bad command-line options, etc)
- */
 int
-GNUNET_GTK_main_loop_start (const char *binary_name,
-                            const char *binary_help,
-                            int argc,
-                            char *const *argv,
-                            struct GNUNET_GETOPT_CommandLineOption *options,
-                            const char *main_window_file,
-                            GNUNET_SCHEDULER_TaskCallback main_task)
+GNUNET_GTK_main_loop_start (
+  const struct GNUNET_OS_ProjectData *pd,
+  const char *binary_name,
+  const char *binary_help,
+  int argc,
+  char *const *argv,
+  struct GNUNET_GETOPT_CommandLineOption *options,
+  const char *main_window_file,
+  GNUNET_SCHEDULER_TaskCallback main_task)
 {
   struct GNUNET_GTK_MainLoop ml;
   int ret;
+  unsigned int olen = 0;
 
   memset (&ml, 0, sizeof (ml));
   ml.main_window_file = main_window_file;
   ml.main_task = main_task;
-  ret = GNUNET_PROGRAM_run (argc,
-                            argv,
-                            binary_name,
-                            binary_help,
-                            options,
-                            &run_main_loop,
-                            &ml);
+  while (NULL != options[olen].name)
+    olen++;
+  {
+    struct GNUNET_GETOPT_CommandLineOption ox[] = {
+      GNUNET_GETOPT_option_string ('C',
+                                   "gnunet-config",
+                                   "FILENAME",
+                                   "configuration file used by GNUnet core",
+                                   &ml.gnunet_cfgfile)
+    };
+    struct GNUNET_GETOPT_CommandLineOption *o2;
+
+    o2 = GNUNET_new_array (olen + 2,
+                           struct GNUNET_GETOPT_CommandLineOption);
+    memcpy (&o2[0],
+            &ox,
+            sizeof (struct GNUNET_GETOPT_CommandLineOption));
+    memcpy (&o2[1],
+            options,
+            sizeof (struct GNUNET_GETOPT_CommandLineOption) * olen);
+    ret = GNUNET_PROGRAM_run (pd,
+                              argc,
+                              argv,
+                              binary_name,
+                              binary_help,
+                              o2,
+                              &run_main_loop,
+                              &ml);
+    GNUNET_free (o2);
+  }
+
+
   if (NULL != ml.cached_poll_array)
     g_free (ml.cached_poll_array);
   if (NULL != ml.rs)
@@ -565,12 +665,18 @@ GNUNET_GTK_main_loop_start (const char *binary_name,
     g_object_unref (G_OBJECT (ml.builder));
   if (NULL != ml.gml)
     g_main_loop_unref (ml.gml);
-  if (NULL != ml.cfg)
+  if (NULL != ml.gnunet_cfg)
   {
-    GNUNET_CONFIGURATION_destroy (ml.cfg);
-    ml.cfg = NULL;
+    GNUNET_CONFIGURATION_destroy (ml.gnunet_cfg);
+    ml.gnunet_cfg = NULL;
   }
-  GNUNET_free (ml.cfgfile);
+  if (NULL != ml.gnunet_gtk_cfg)
+  {
+    GNUNET_CONFIGURATION_destroy (ml.gnunet_gtk_cfg);
+    ml.gnunet_gtk_cfg = NULL;
+  }
+  GNUNET_free (ml.gnunet_cfgfile);
+  GNUNET_free (ml.gnunet_gtk_cfgfile);
   return ret;
 }
 
