@@ -124,7 +124,7 @@ phone_validate (void *cls, GtkBuilder *builder)
 {
   GtkEditable *entry;
   const gchar *preedit;
-  struct GNUNET_IDENTITY_PublicKey pub;
+  struct GNUNET_CRYPTO_PublicKey pub;
 
   entry = GTK_EDITABLE (
     gtk_builder_get_object (builder, "edit_dialog_phone_peer_entry"));
@@ -135,7 +135,7 @@ phone_validate (void *cls, GtkBuilder *builder)
                                                    strlen (preedit),
                                                    &pub.ecdsa_key)))
     return GNUNET_SYSERR;
-  pub.type = GNUNET_IDENTITY_TYPE_ECDSA;
+  pub.type = GNUNET_PUBLIC_KEY_TYPE_ECDSA;
   return GNUNET_OK;
 }
 
