@@ -45,14 +45,18 @@ dnc_dummy (void *cls, const struct GNUNET_HashCode *key, size_t size)
 static int
 test_config (const char *name)
 {
-  struct GNUNET_DATACACHE_PluginEnvironment env = {cfg,
-                                                   "dhtcache",
-                                                   NULL,
-                                                   &dnc_dummy,
-                                                   1024LL};
+  struct GNUNET_DATACACHE_PluginEnvironment env = {
+    cfg,
+    "dhtcache",
+    NULL,
+    &dnc_dummy,
+    1024LL
+  };
   void *ret;
 
-  ret = GNUNET_PLUGIN_load (name, &env);
+  ret = GNUNET_PLUGIN_load (GNUNET_OS_project_data_gnunet (),
+                            name,
+                            &env);
   if (NULL == ret)
     return GNUNET_SYSERR;
   GNUNET_PLUGIN_unload (name, ret);
