@@ -33,9 +33,12 @@
  * @param name name of the plugin to check
  */
 static void
-test_plugin (GtkWidget *widget, const char *name)
+test_plugin (GtkWidget *widget,
+             const char *name)
 {
-  if (GNUNET_YES == GNUNET_PLUGIN_test (name))
+  if (GNUNET_YES ==
+      GNUNET_PLUGIN_test (GNUNET_OS_project_data_gnunet (),
+                          name))
   {
     gtk_widget_set_sensitive (widget, TRUE);
   }
