@@ -340,9 +340,13 @@ write_configuration ()
   struct GNUNET_CONFIGURATION_Handle *cfgDefault;
   int ret;
 
-  cfgDefault = GNUNET_CONFIGURATION_create ();
-  (void) GNUNET_CONFIGURATION_load (cfgDefault, NULL); /* load defaults only */
-  ret = GNUNET_CONFIGURATION_write_diffs (cfgDefault, cfg, option_cfg_name);
+  cfgDefault = GNUNET_CONFIGURATION_create (
+    GNUNET_OS_project_data_gnunet ());
+  (void) GNUNET_CONFIGURATION_load (cfgDefault,
+                                    NULL); /* load defaults only */
+  ret = GNUNET_CONFIGURATION_write_diffs (cfgDefault,
+                                          cfg,
+                                          option_cfg_name);
   GNUNET_CONFIGURATION_destroy (cfgDefault);
   return ret;
 }
@@ -373,7 +377,8 @@ cleanup_task (void *cls)
  * Callback invoked if the application is supposed to exit.
  */
 void
-GNUNET_SETUP_quit_cb (GObject *object, gpointer user_data)
+GNUNET_SETUP_quit_cb (GObject *object,
+                      gpointer user_data)
 {
   GNUNET_SCHEDULER_shutdown ();
 }
@@ -461,8 +466,11 @@ run (void *cls)
 
   my_uid = getuid ();
   gnunet_pw = getpwnam ("gnunet");
-  if ((0 != do_gksu) && (0 != my_uid) && (NULL != gnunet_pw) &&
-      (my_uid != gnunet_pw->pw_uid) && (GNUNET_OK == try_gksu ("gnunet")))
+  if ( (0 != do_gksu) &&
+       (0 != my_uid) &&
+       (NULL != gnunet_pw) &&
+       (my_uid != gnunet_pw->pw_uid) &&
+       (GNUNET_OK == try_gksu ("gnunet")))
   {
     GNUNET_GTK_main_loop_quit (cls);
     return;
@@ -470,16 +478,20 @@ run (void *cls)
 #endif
 
   ml = cls;
-  if (GNUNET_OK != GNUNET_GTK_main_loop_build_window (ml, NULL))
+  if (GNUNET_OK != GNUNET_GTK_main_loop_build_window (ml,
+                                                      NULL))
     return;
 
-  option_cfg_name = GNUNET_GTK_main_loop_get_configuration_file (ml);
-  cfg = GNUNET_CONFIGURATION_create ();
+  option_cfg_name = GNUNET_GTK_main_loop_get_gnunet_configuration_file (ml);
+  cfg = GNUNET_CONFIGURATION_create (GNUNET_OS_project_data_gnunet ());
   if (GNUNET_YES == GNUNET_DISK_file_test (option_cfg_name))
-    (void) GNUNET_CONFIGURATION_load (cfg, option_cfg_name);
+    (void) GNUNET_CONFIGURATION_load (cfg,
+                                      option_cfg_name);
   else
-    (void) GNUNET_CONFIGURATION_load (cfg, NULL);
-  if (0 != access (option_cfg_name, W_OK))
+    (void) GNUNET_CONFIGURATION_load (cfg,
+                                      NULL);
+  if (0 != access (option_cfg_name,
+                   W_OK))
   {
     if (ENOENT == errno)
     {
@@ -513,7 +525,8 @@ run (void *cls)
   }
   main_window = GTK_WIDGET (GNUNET_SETUP_get_object ("GNUNET_setup_dialog"));
   load_options ();
-  GNUNET_SCHEDULER_add_shutdown (&cleanup_task, NULL);
+  GNUNET_SCHEDULER_add_shutdown (&cleanup_task,
+                                 NULL);
   gtk_widget_show (main_window);
   gtk_window_present (GTK_WINDOW (main_window));
 }
@@ -527,7 +540,8 @@ run (void *cls)
  * @return 0 on success
  */
 int
-main (int argc, char *const *argv)
+main (int argc,
+      char *const *argv)
 {
   struct GNUNET_GETOPT_CommandLineOption options[] = {
 #ifndef MINGW
@@ -542,13 +556,15 @@ main (int argc, char *const *argv)
   };
   int ret;
 
-  if (GNUNET_OK == GNUNET_GTK_main_loop_start ("gnunet-setup",
-                                               "gnunet-setup",
-                                               argc,
-                                               argv,
-                                               options,
-                                               "gnunet_setup_main_window.glade",
-                                               &run))
+  if (GNUNET_OK ==
+      GNUNET_GTK_main_loop_start (GNUNET_GTK_project_data (),
+                                  "gnunet-setup",
+                                  "gnunet-setup",
+                                  argc,
+                                  argv,
+                                  options,
+                                  "gnunet_setup_main_window.glade",
+                                  &run))
     ret = gret;
   else
     ret = 1;
