@@ -64,48 +64,48 @@ struct PlotInfo
  * Selected statistics for the connection tab.
  */
 static const struct PlotInfo connection_data[] =
-  {{"fs", "# peers connected", "file-sharing connections", "blue"},
-   {"core", "# peers connected", "encrypted connections (core)", "green"},
-   {"core",
-    "# neighbour entries allocated",
-    "transport connections (core)",
-    "yellow"},
-   {"transport",
-    "# peers connected",
-    "total connections (transport)",
-    "orange"},
-   {"transport", "# TCP sessions active", "tcp connections", "red"},
-   {"transport", "# UDP sessions active", "udp connections", "gray"},
-   {"dht", "# peers connected", "DHT connections", "brown"},
-   {"nse",
-    "# nodes in the network (estimate)",
-    "network size (estimate)",
-    "purple"},
-   {NULL, NULL, NULL}};
+{{"fs", "# peers connected", "file-sharing connections", "blue"},
+ {"core", "# peers connected", "encrypted connections (core)", "green"},
+ {"core",
+  "# neighbour entries allocated",
+  "transport connections (core)",
+  "yellow"},
+ {"transport",
+  "# peers connected",
+  "total connections (transport)",
+  "orange"},
+ {"transport", "# TCP sessions active", "tcp connections", "red"},
+ {"transport", "# UDP sessions active", "udp connections", "gray"},
+ {"dht", "# peers connected", "DHT connections", "brown"},
+ {"nse",
+  "# nodes in the network (estimate)",
+  "network size (estimate)",
+  "purple"},
+ {NULL, NULL, NULL}};
 
 
 /**
  * Selected statistics for the traffic tab.
  */
 static const struct PlotInfo traffic_data[] =
-  {{"core", "# bytes encrypted", "bytes encrypted", "blue"},
-   {"core", "# bytes decrypted", "bytes decrypted", "green"},
-   {"transport", "# bytes received via TCP", "received via tcp", "yellow"},
-   {"transport", "# bytes transmitted via TCP", "sent via tcp", "brown"},
-   {NULL, NULL, NULL}};
+{{"core", "# bytes encrypted", "bytes encrypted", "blue"},
+ {"core", "# bytes decrypted", "bytes decrypted", "green"},
+ {"transport", "# bytes received via TCP", "received via tcp", "yellow"},
+ {"transport", "# bytes transmitted via TCP", "sent via tcp", "brown"},
+ {NULL, NULL, NULL}};
 
 
 /**
  * Selected statistics for the storage tab.
  */
 static const struct PlotInfo storage_data[] =
-  {{"datastore", "# quota", "datastore capacity", "blue"},
-   {"datastore",
-    "# utilization by current datastore",
-    "datastore utilization",
-    "yellow"},
-   {"datastore", "# cache size", "reservation for datastore cache", "green"},
-   {NULL, NULL, NULL}};
+{{"datastore", "# quota", "datastore capacity", "blue"},
+ {"datastore",
+  "# utilization by current datastore",
+  "datastore utilization",
+  "yellow"},
+ {"datastore", "# cache size", "reservation for datastore cache", "green"},
+ {NULL, NULL, NULL}};
 
 
 /**
@@ -148,8 +148,8 @@ process_value_update (void *cls,
   gtk_statistics_update_value (stats,
                                id,
                                GNUNET_TIME_absolute_get_duration (start_time)
-                                   .rel_value_us /
-                                 1000000LL,
+                               .rel_value_us
+                               / 1000000LL,
                                value);
   GNUNET_free (id);
   return GNUNET_OK;
@@ -244,7 +244,8 @@ run (void *cls)
 
   statistics =
     GNUNET_STATISTICS_create ("gnunet-statistics-gtk",
-                              GNUNET_GTK_main_loop_get_configuration (ml));
+                              GNUNET_GTK_main_loop_get_gnunet_configuration (ml)
+                              );
   if (NULL == statistics)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
@@ -256,7 +257,6 @@ run (void *cls)
 
   /* setup main window */
   main_window = GTK_WIDGET (get_object ("GNUNET_STATISTICS_GTK_main_window"));
-  main_window = GNUNET_GTK_plug_me ("GNUNET_STATISTICS_GTK_PLUG", main_window);
   gtk_window_maximize (GTK_WINDOW (main_window));
   create_plot ("GNUNET_STATISTICS_GTK_connectivity_box", connection_data);
   create_plot ("GNUNET_STATISTICS_GTK_traffic_box", traffic_data);
@@ -273,11 +273,13 @@ int
 main (int argc, char *const *argv)
 {
   static struct GNUNET_GETOPT_CommandLineOption options[] = {
-    GNUNET_GETOPT_OPTION_END};
+    GNUNET_GETOPT_OPTION_END
+  };
 
   start_time = GNUNET_TIME_absolute_get ();
   if (GNUNET_OK !=
-      GNUNET_GTK_main_loop_start ("gnunet-statistics-gtk",
+      GNUNET_GTK_main_loop_start (GNUNET_GTK_project_data (),
+                                  "gnunet-statistics-gtk",
                                   "GTK GUI for viewing GNUnet statistics",
                                   argc,
                                   argv,
